package com.da.dangan.mapper;

import com.da.dangan.domain.AreaSort;

import java.util.List;

/**
 * 档案行政分类Mapper接口
 * 
 * @author hs
 * @date 2024-05-11
 */
public interface AreaSortMapper 
{
    /**
     * 查询档案行政分类
     * 
     * @param id 档案行政分类主键
     * @return 档案行政分类
     */
    public AreaSort selectAreaSortById(Long id);

    /**
     * 查询档案行政分类列表
     * 
     * @param areaSort 档案行政分类
     * @return 档案行政分类集合
     */
    public List<AreaSort> selectAreaSortList(AreaSort areaSort);

    /**
     * 新增档案行政分类
     * 
     * @param areaSort 档案行政分类
     * @return 结果
     */
    public int insertAreaSort(AreaSort areaSort);

    /**
     * 修改档案行政分类
     * 
     * @param areaSort 档案行政分类
     * @return 结果
     */
    public int updateAreaSort(AreaSort areaSort);

    /**
     * 删除档案行政分类
     * 
     * @param id 档案行政分类主键
     * @return 结果
     */
    public int deleteAreaSortById(Long id);

    /**
     * 批量删除档案行政分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAreaSortByIds(Long[] ids);
}
